# lightkube-extensions
A collection of helpers and shared code for using [Lightkube](lightkube-rtd)

Many of these helpers are vendored from or inspired by [Charmed Kubeflow Chisme](chisme-github)

[lightkube-rtd]: https://lightkube.readthedocs.io/en/latest/
[chisme-github]: https://github.com/canonical/charmed-kubeflow-chisme
